@@ -332,7 +332,8 @@ typedef struct
 	char	   *ssl_ca_cert;	/* path to root (CA) certificate */
 	char	   *ssl_ca_cert_dir;	/* path to directory containing CA
 									 * certificates */
-
+	char	   *ssl_ciphers;	/* allowed ssl ciphers */
+	bool		ssl_prefer_server_ciphers; /*Use SSL cipher preferences, rather than the client's*/
 	int64		relcache_expire;	/* relation cache life time in seconds */
 	int			relcache_size;	/* number of relation cache life entry */
 	bool		check_temp_table;	/* enable temporary table check */
